@@ -47,7 +47,8 @@ Planet.Core.rhoFe_kgm3 = 8000.0
 Planet.Core.rhoFeS_kgm3 = 5150.0
 Planet.Core.rhoPoFeFCC = 5455.0
 Planet.Core.QScore = 1e4
-Planet.Core.coreEOS = 'Fe085_S015.tab'
+Planet.Core.coreEOS = 'Fe-S_3D_EOS.mat'
+Planet.Core.wFe_ppt = 850
 Planet.Core.xFeSmeteoritic = 0.0405
 Planet.Core.xFeS = 0.55
 Planet.Core.xFeCore = 0.0279
@@ -55,9 +56,3 @@ Planet.Core.xH2O = 0.0035
 
 """ Seismic properties of solids """
 Planet.Seismic.lowQDiv = 1.0
-
-""" Magnetic induction """
-Planet.Magnetic.peaks_Hz = np.array([4.946e-5, 2.473e-5, 3.259e-6])
-Planet.Magnetic.fOrb_radps = 2*np.pi/3.55/86400
-Planet.Magnetic.ionosBounds_m = 100e3
-Planet.Magnetic.sigmaIonosPedersen_Sm = 30/100e3
